============
CONTRIBUTING
============

First, thank you very much, that you would like to contribute to django CMS.
We always welcome contributions, like many other open-source projects. We are
very thankful to the many `present, past and future contributors <https://github.com/divio/django-cms/graphs/contributors>`_.


Code of Conduct
===============

django CMS is governed by a `Code of Conduct
<http://docs.django-cms.org/en/latest/contributing/code_of_conduct.html>`_.
All participants in our community and its various forums are expected to abide by it.


Issues and pull requests
========================

* Please report **any bugs** through `GitHub issues <https://github.com/divio/django-cms/issues>`_.
* For *help with django CMS*, please use our `users' email list <https://groups.google.com/forum/#!forum/django-cms>`_
  or `StackOverflow <https://stackoverflow.com/questions/tagged/django-cms>`_.
* For *feature requests*, please use our
  `developers' email list <https://groups.google.com/forum/#!forum/django-cms-developers>`_.
* For *security issues* please see further below.


Contribution documentation
==========================

We maintain comprehensive `contribution documentation <http://docs.django-cms.org/en/latest/contributing/>`_.
Please familiarise yourself with it before submitting any issues or pull requests.


Security issues
===============

Please have a look at our security policy for
`how to deal with security issues <http://docs.django-cms.org/en/latest/contributing/development-policies.html#reporting-security-issues>`_.

If you think you have discovered a security issue in our code, please do not raise it on

* GitHub
* StackOverflow
* IRC
* Twitter
* either of our email lists

or in any other public forum until we have had a chance to deal with it.


Community
=========

You can join us online:

* on `StackOverflow <https://stackoverflow.com/questions/tagged/django-cms>`_.
* in our IRC channel, #django-cms, on ``irc.freenode.net``. If you don't have an IRC client, you can
  `join our IRC channel using the KiwiIRC web client
  <https://kiwiirc.com/client/irc.freenode.net/django-cms>`_, which works pretty well.
* on our `django CMS users email list <https://groups.google.com/forum/#!forum/django-cms>`_ for
  **general** django CMS questions and discussion
* on our `django CMS developers email list
  <https://groups.google.com/forum/#!forum/django-cms-developers>`_ for discussions about the
  **development of django CMS**

You can also follow:

* the `Travis Continuous Integration build reports <https://travis-ci.org/divio/django-cms>`_
* the `@djangocms <https://twitter.com/djangocms>`_ Twitter account for general announcements
